**Example 1: 隔离集群**



Input: 

```
tccli tdcpg DeleteCluster --cli-unfold-argument  \
    --ClusterId tdcpg-xxx
```

Output: 
```
{
    "Response": {
        "RequestId": "03ea3f94-297d-11eb-8f30-525400b7dd5a"
    }
}
```

